@@ -247,7 +247,7 @@ async def on_message(message):
                                 subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
                             if platform.system() != "Windows":
                                 command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
-                                subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
+                                subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
 
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
